@@ -1,11 +1,9 @@
 """Structlog Sentry Logger"""
-
 from typing import List
 
-import sentry_sdk
-from dotenv import find_dotenv, load_dotenv
-
 from structlog_sentry_logger._config import (
+    _init_sentry,
+    _load_library_specific_env_vars,
     get_config_dict,
     get_logger,
     get_namespaced_module_name,
@@ -19,6 +17,5 @@ __all__: List[str] = [
     "getLogger",
 ]
 
-load_dotenv(find_dotenv())
-# Note: if DSN isn't defined, will silently not transmit telemetry
-sentry_sdk.init()  # pylint: disable=abstract-class-instantiated
+_load_library_specific_env_vars()
+_ = _init_sentry()
