@@ -136,7 +136,8 @@ def get_logging_config(
 def set_logging_config(
     module_name: str, timestamper: structlog.processors.TimeStamper
 ) -> None:
-    logging.config.dictConfig(get_logging_config(module_name, timestamper))
+    config_dict = get_logging_config(module_name, timestamper)
+    logging.config.dictConfig(config_dict)
 
 
 def get_formatters(timestamper: structlog.processors.TimeStamper) -> dict:
@@ -209,7 +210,6 @@ def set_structlog_config(timestamper: structlog.processors.TimeStamper) -> None:
     structlog_processors = [
         timestamper,
         structlog.processors.StackInfoRenderer(),
-        structlog.processors.format_exc_info,
         add_severity_field_from_level_if_in_cloud_environment,
     ]
     stdlib_log_compatibility_processors = [
